==> javascript-frontend-2.21.0.4409-sources.jar: org/sonar/plugins/javascript/api/tree/statement/IfStatementTree.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.plugins.javascript.api.tree.statement;

import com.google.common.annotations.Beta;
import javax.annotation.Nullable;
import org.sonar.plugins.javascript.api.tree.expression.ExpressionTree;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;

/**
 * <a href="http://www.ecma-international.org/ecma-262/5.1/#sec-12.5">if Statement</a>.
 * <pre>
 *   if ({@link #condition()}) {@link #statement()}
 *   if ({@link #condition()}) {@link #statement()} {@link #elseClause()}
 * </pre>
 */
@Beta
public interface IfStatementTree extends StatementTree {

  SyntaxToken ifKeyword();

  SyntaxToken openParenthesis();

  ExpressionTree condition();

  SyntaxToken closeParenthesis();

  StatementTree statement();

  @Nullable
  ElseClauseTree elseClause();

}

==> javascript-frontend-3.1.0.5111-sources.jar: org/sonar/plugins/javascript/api/tree/statement/IfStatementTree.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.plugins.javascript.api.tree.statement;

import com.google.common.annotations.Beta;
import javax.annotation.Nullable;
import org.sonar.plugins.javascript.api.tree.expression.ExpressionTree;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;

/**
 * <a href="http://www.ecma-international.org/ecma-262/5.1/#sec-12.5">if Statement</a>.
 * <pre>
 *   if ({@link #condition()}) {@link #statement()}
 *   if ({@link #condition()}) {@link #statement()} {@link #elseClause()}
 * </pre>
 */
@Beta
public interface IfStatementTree extends StatementTree, ConditionalTree {

  SyntaxToken ifKeyword();

  SyntaxToken openParenthesisToken();

  ExpressionTree condition();

  SyntaxToken closeParenthesisToken();

  StatementTree statement();

  @Nullable
  ElseClauseTree elseClause();

}
